/*
 * build.h
 * Automatically generated
 */
#define BUILD_HOSTNAME "riscv64-4.ports.openbsd.org"
#define BUILD_KERNEL "7.8"
#define BUILD_MACHINE "riscv64"
#define BUILD_OS "OpenBSD"
#define BUILD_DATE "2025-12-09 18:21:48 UTC"
#define BUILD_USER "_pbuild"

